@@ -18,14 +18,17 @@ INTITULE = 'intitule'
 NOM = u'nom'
 NUMERO = u'numero'
 NUMERO_COMPTE = u'numero_compte'
+NUMERO_LIGNE_ECRITURE_DEBUT = u'numero_ligne_debut'
+NUMERO_LIGNE_ECRITURE_FIN = u'numero_ligne_fin'
 
 CATEGORIE = u'categorie'
 RUBRIQUES = u'rubriques'
 
 COMPTES = u'comptes'
 
+
 def titre_principal_rst(titre, date_debut, date_fin):
     return [
         rst_title(titre), "\n",
-        rst_title(u"Période du %s au %s" % (date_debut,date_fin), '-'), "\n",
+        rst_title(u"Période du %s au %s" % (date_debut, date_fin), '-'), "\n",
     ]
