@@ -21,57 +21,57 @@ class LivreJournalTestCase(unittest.TestCase):
         result = check_livre_journal(livre_journal)
         self.assertEqual(
             result,
-            [[u'18/03/2011 - Frais de constitution de la soci\xe9t\xe9 CFE Paris.',
-              u'OK : d\xe9bit = cr\xe9dit (90.45).'],
-             [u'18/03/2011 - Frais de constitution de la soci\xe9t\xe9 - Annonce l\xe9gale.',
-              u'OK : d\xe9bit = cr\xe9dit (99.00).'],
+            [[u'18/03/2011 - Frais de constitution de la société CFE Paris.',
+              u'OK : débit = crédit (90.45).'],
+             [u'18/03/2011 - Frais de constitution de la société - Annonce légale.',
+              u'OK : débit = crédit (99.00).'],
              [u'31/03/2011 - Facture 2011-01 MyClient1 Prestation MyClient1 mars 2011',
-              u'OK : d\xe9bit = cr\xe9dit (5980.00).'],
-             [u'01/04/2011 - R\xe9sultat arr\xeat\xe9 compte',
-              u'OK : d\xe9bit = cr\xe9dit (48.00).'],
-             [u'02/04/2011 - Capital initial D\xe9p\xf4t de 1500 \u20ac par Stanislas Guerra au LCL Ledru Rollin',
-              u'OK : d\xe9bit = cr\xe9dit (1500.00).'],
+              u'OK : débit = crédit (5 980.00).'],
+             [u'01/04/2011 - Résultat arrêté compte',
+              u'OK : débit = crédit (48.00).'],
+             [u'02/04/2011 - Capital initial Dép\xf4t de 1500 € par Stanislas Guerra au LCL Ledru Rollin',
+              u'OK : débit = crédit (1 500.00).'],
              [u'04/04/2011 - Facture 2011-02 MyClient2 Prestation MyClient2',
-              u'OK : d\xe9bit = cr\xe9dit (1794.00).'],
+              u'OK : débit = crédit (1 794.00).'],
              [u'28/04/2011 - Cotisation Option PRO  LCL',
-              u'OK : d\xe9bit = cr\xe9dit (15.00).'],
-             [u'02/05/2011 - Abonnement LCL Access', u'OK : d\xe9bit = cr\xe9dit (3.00).'],
+              u'OK : débit = crédit (15.00).'],
+             [u'02/05/2011 - Abonnement LCL Access', u'OK : débit = crédit (3.00).'],
              [u'11/06/2011 - BHV - Fournitures des bureau (Livres comptables).',
-              u'OK : d\xe9bit = cr\xe9dit (25.65).'],
-             [u'15/06/2011 - Remise ch\xe8que XXXXXXX r\xe8glement facture 2011-02',
-              u'OK : d\xe9bit = cr\xe9dit (2088.00).'],
-             [u'05/07/2011 - Traitement mois de juin g\xe9rant.',
-              u'OK : d\xe9bit = cr\xe9dit (3000.00).'],
-             [u'08/08/2011 - Ch\xe8que XXXXXXY Cotisation trimestrielle RSI/Pr\xe9vadi\xe8s.',
-              u'OK : d\xe9bit = cr\xe9dit (393.00).'],
+              u'OK : débit = crédit (25.65).'],
+             [u'15/06/2011 - Remise chèque XXXXXXX règlement facture 2011-02',
+              u'OK : débit = crédit (2 088.00).'],
+             [u'05/07/2011 - Traitement mois de juin gérant.',
+              u'OK : débit = crédit (3 000.00).'],
+             [u'08/08/2011 - Chèque XXXXXXY Cotisation trimestrielle RSI/Prévadiès.',
+              u'OK : débit = crédit (393.00).'],
              [u'02/09/2011 - Virement MyClient1 ZZZZZZZZZZZ Facture 2011-01',
-              u'OK : d\xe9bit = cr\xe9dit (6960.00).'],
-             [u'03/09/2011 - Abonnement LCL Access', u'OK : d\xe9bit = cr\xe9dit (3.00).'],
+              u'OK : débit = crédit (6 960.00).'],
+             [u'03/09/2011 - Abonnement LCL Access', u'OK : débit = crédit (3.00).'],
              [u'28/09/2011 - Facture 2011-04 MyClient1 Prestation aout 2011',
-              u'OK : d\xe9bit = cr\xe9dit (13156.00).'],
+              u'OK : débit = crédit (13 156.00).'],
              [u'30/09/2011 - Solde des comptes de TVA du 01/03/2011 au 30/09/2011',
-              u'OK : d\xe9bit = cr\xe9dit (1274.00).'],
-             [u'06/10/2011 - Ch\xe8que WWWWWWW R\xe8glement de la TVA trimestrielle',
-              u'OK : d\xe9bit = cr\xe9dit (1240.00).'],
+              u'OK : débit = crédit (1 274.00).'],
+             [u'06/10/2011 - Chèque WWWWWWW Règlement de la TVA trimestrielle',
+              u'OK : débit = crédit (1 240.00).'],
              [u'01/11/2011 - Facture 2011-05 MyClient1 Prestation septembre 2011',
-              u'OK : d\xe9bit = cr\xe9dit (5382.00).'],
-             [u'17/11/2011 - Ch\xe8que ZZZZZZZ Cotisation sociales Urssaf 4\xe8me trimestre.',
-              u'OK : d\xe9bit = cr\xe9dit (402.00).'],
-             [u'01/12/2011 - Abonnement LCL Access', u'OK : d\xe9bit = cr\xe9dit (3.00).'],
+              u'OK : débit = crédit (5 382.00).'],
+             [u'17/11/2011 - Chèque ZZZZZZZ Cotisation sociales Urssaf 4ème trimestre.',
+              u'OK : débit = crédit (402.00).'],
+             [u'01/12/2011 - Abonnement LCL Access', u'OK : débit = crédit (3.00).'],
              [u'01/12/2011 - Virement MyClient1 WWWWWWWWWW Facture 2011-04, 2011-05',
-              u'OK : d\xe9bit = cr\xe9dit (21576.00).'],
+              u'OK : débit = crédit (21 576.00).'],
              [u'01/12/2011 - Facture 2011-06 MyClient3',
-              u'OK : d\xe9bit = cr\xe9dit (8372.00).'],
+              u'OK : débit = crédit (8 372.00).'],
              [u'31/12/2011 - Solde des comptes de TVA du 01/10/2011 au 31/12/2011',
-              u'OK : d\xe9bit = cr\xe9dit (3038.00).'],
-             [u'31/12/2011 - Prestation MyClient1 d\xe9cembre 2011',
-              u'OK : d\xe9bit = cr\xe9dit (13156.00).'],
-             [u'01/01/2012 - Prestation MyClient1 d\xe9cembre 2011',
-              u'OK : d\xe9bit = cr\xe9dit (13156.00).'],
-             [u'03/01/2012 - Facture 2012-01 MyClient1 Prestation d\xe9cembre 2011',
-              u'OK : d\xe9bit = cr\xe9dit (13156.00).'],
-             [u"01/02/2012 - Restaurant La Tour d'argent D\xe9jeuner d'affaire avec Steve Jobs 0.88\u20ac TVA 19.6% ; 2.90\u20ac TVA 7.0%",
-              u'OK : d\xe9bit = cr\xe9dit (49.80).']]
+              u'OK : débit = crédit (3 038.00).'],
+             [u'31/12/2011 - Prestation MyClient1 décembre 2011',
+              u'OK : débit = crédit (13 156.00).'],
+             [u'01/01/2012 - Prestation MyClient1 décembre 2011',
+              u'OK : débit = crédit (13 156.00).'],
+             [u'03/01/2012 - Facture 2012-01 MyClient1 Prestation décembre 2011',
+              u'OK : débit = crédit (13 156.00).'],
+             [u"01/02/2012 - Restaurant La Tour d'argent Déjeuner d'affaire avec Steve Jobs 0.88€ TVA 19.6% ; 2.90€ TVA 7.0%",
+              u'OK : débit = crédit (49.80).']]
         )
 
     def test_ecritures_de_cloture(self):
@@ -140,12 +140,12 @@ class LivreJournalTestCase(unittest.TestCase):
                              'numero_compte_debit': u''},
                             {'credit': Decimal('153.31'),
                              'debit': Decimal('0.00'),
-                             'nom_compte': u'Charges - cotisations URSSAF - CSG/RDS d\xe9ductible',
+                             'nom_compte': u'Charges - cotisations URSSAF - CSG/RDS déductible',
                              'numero_compte_credit': u'6411-URSF2',
                              'numero_compte_debit': u''},
                             {'credit': Decimal('86.89'),
                              'debit': Decimal('0.00'),
-                             'nom_compte': u'Charges - cotisations URSSAF - CSG/RDS non-d\xe9ductible',
+                             'nom_compte': u'Charges - cotisations URSSAF - CSG/RDS non-déductible',
                              'numero_compte_credit': u'6411-URSF3',
                              'numero_compte_debit': u''}],
               'intitule': u'Ecritures de cl\xf4ture des comptes.'},
@@ -162,10 +162,10 @@ class LivreJournalTestCase(unittest.TestCase):
                              'numero_compte_debit': u''},
                             {'credit': Decimal('35951.90'),
                              'debit': Decimal('0.0'),
-                             'nom_compte': u"r\xe9sultat de l'exercice (b\xe9n\xe9fice)",
+                             'nom_compte': u"résultat de l'exercice (bénéfice)",
                              'numero_compte_credit': '120',
                              'numero_compte_debit': u''}],
-              'intitule': u"Enregistrement du r\xe9sultat net de l'exercice"}]
+              'intitule': u"Enregistrement du résultat net de l'exercice"}]
         )
 
     def test_ecritures_to_livre_journal(self):
@@ -180,25 +180,25 @@ u"""+---------------------------------------------------------------------------
 | Ecritures pour le Livre-journal                                                                                                                    |
 +=============+=================+=================+==============================================================+=================+=================+
 || 31/12/2011 ||                ||                || Ecritures de clôture des comptes.                           ||                ||                |
-||            || 706            ||                || Produits - prestations de services                          || 40000.00       ||                |
+||            || 706            ||                || Produits - prestations de services                          || 40 000.00      ||                |
 ||            || 758            ||                || Produits divers de gestion courante                         || 0.34           ||                |
-||            ||                || 127            ||     Regroupement des comptes de produits                    ||                || 40000.34       |
+||            ||                || 127            ||     Regroupement des comptes de produits                    ||                || 40 000.34      |
 +-------------+-----------------+-----------------+--------------------------------------------------------------+-----------------+-----------------+
 || 31/12/2011 ||                ||                || Ecritures de clôture des comptes.                           ||                ||                |
-||            || 126            ||                || Regroupement des comptes de charges                         || 4048.44        ||                |
+||            || 126            ||                || Regroupement des comptes de charges                         || 4 048.44       ||                |
 ||            ||                || 60225          ||     Achats - Fournitures de bureau                          ||                || 21.44          |
 ||            ||                || 6227           ||     Achats - Frais d'actes et de contentieux                ||                || 160.00         |
 ||            ||                || 6278-LCL       ||     Autres frais de commission sur prestations de services  ||                || 72.00          |
-||            ||                || 6411           ||     Charges - Salaires et appointements                     ||                || 3000.00        |
+||            ||                || 6411           ||     Charges - Salaires et appointements                     ||                || 3 000.00       |
 ||            ||                || 6411-RSI       ||     Charges - cotisations RSI                               ||                || 393.00         |
 ||            ||                || 6411-URSF1     ||     Charges - cotisations URSSAF - Allocations familliales  ||                || 161.80         |
 ||            ||                || 6411-URSF2     ||     Charges - cotisations URSSAF - CSG/RDS déductible       ||                || 153.31         |
 ||            ||                || 6411-URSF3     ||     Charges - cotisations URSSAF - CSG/RDS non-déductible   ||                || 86.89          |
 +-------------+-----------------+-----------------+--------------------------------------------------------------+-----------------+-----------------+
 || 31/12/2011 ||                ||                || Enregistrement du résultat net de l'exercice                ||                ||                |
-||            || 127            ||                || Regroupement des comptes de produits                        || 40000.34       ||                |
-||            ||                || 126            ||     Regroupement des comptes de charges                     ||                || 4048.44        |
-||            ||                || 120            ||     résultat de l'exercice (bénéfice)                       ||                || 35951.90       |
+||            || 127            ||                || Regroupement des comptes de produits                        || 40 000.34      ||                |
+||            ||                || 126            ||     Regroupement des comptes de charges                     ||                || 4 048.44       |
+||            ||                || 120            ||     résultat de l'exercice (bénéfice)                       ||                || 35 951.90      |
 +-------------+-----------------+-----------------+--------------------------------------------------------------+-----------------+-----------------+
 
 """)
@@ -267,34 +267,34 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u'6227'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('10.45'),
-                              'nom_compte': u'T.V.A. d\xe9ductible sur autres biens et services',
+                              'nom_compte': u'T.V.A. déductible sur autres biens et services',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44566'},
                              {u'credit': Decimal('90.45'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Associ\xe9s - Comptes courants',
+                              'nom_compte': u'Associés - Comptes courants',
                               'numero_compte_credit': u'455',
                               'numero_compte_debit': u''}],
-              'intitule': u'Frais de constitution de la soci\xe9t\xe9 CFE Paris.',
+              'intitule': u'Frais de constitution de la société CFE Paris.',
               u'numero_ligne_debut': 13,
               u'numero_ligne_fin': 17},
              {'date': datetime.date(2011, 3, 18),
               u'ecritures': [{u'credit': Decimal('0.00'),
                               u'debit': Decimal('80.00'),
-                              'nom_compte': u"Achats - Frais d'actes et de contentieux MONTANT \xe0 v\xe9rifier",
+                              'nom_compte': u"Achats - Frais d'actes et de contentieux MONTANT à vérifier",
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'6227'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('19.00'),
-                              'nom_compte': u'T.V.A. d\xe9ductible sur autres biens et services',
+                              'nom_compte': u'T.V.A. déductible sur autres biens et services',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44566'},
                              {u'credit': Decimal('99.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Associ\xe9s - Comptes courants',
+                              'nom_compte': u'Associés - Comptes courants',
                               'numero_compte_credit': u'455',
                               'numero_compte_debit': u''}],
-              'intitule': u'Frais de constitution de la soci\xe9t\xe9 - Annonce l\xe9gale.',
+              'intitule': u'Frais de constitution de la société - Annonce légale.',
               u'numero_ligne_debut': 18,
               u'numero_ligne_fin': 22},
              {'date': datetime.date(2011, 3, 31),
@@ -310,7 +310,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('980.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'44587',
                               'numero_compte_debit': u''}],
               'intitule': u'Facture 2011-01 MyClient1 Prestation MyClient1 mars 2011',
@@ -327,7 +327,7 @@ u"""+---------------------------------------------------------------------------
                               'nom_compte': u'Banques',
                               'numero_compte_credit': u'512',
                               'numero_compte_debit': u''}],
-              'intitule': u'R\xe9sultat arr\xeat\xe9 compte',
+              'intitule': u'Résultat arrêté compte',
               u'numero_ligne_debut': 31,
               u'numero_ligne_fin': 34},
              {'date': datetime.date(2011, 4, 2),
@@ -341,7 +341,7 @@ u"""+---------------------------------------------------------------------------
                               'nom_compte': u"Capital et compte de l'exploitant",
                               'numero_compte_credit': u'100',
                               'numero_compte_debit': u''}],
-              'intitule': u'Capital initial D\xe9p\xf4t de 1500 \u20ac par Stanislas Guerra au LCL Ledru Rollin',
+              'intitule': u'Capital initial Dép\xf4t de 1500 € par Stanislas Guerra au LCL Ledru Rollin',
               u'numero_ligne_debut': 35,
               u'numero_ligne_fin': 40},
              {'date': datetime.date(2011, 4, 4),
@@ -357,7 +357,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('294.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'44587',
                               'numero_compte_debit': u''}],
               'intitule': u'Facture 2011-02 MyClient2 Prestation MyClient2',
@@ -399,7 +399,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u'60225'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('4.21'),
-                              'nom_compte': u'T.V.A. d\xe9ductible sur autres biens et services',
+                              'nom_compte': u'T.V.A. déductible sur autres biens et services',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44566'},
                              {u'credit': Decimal('25.65'),
@@ -418,7 +418,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u'512'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('294.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44587'},
                              {u'credit': Decimal('1794.00'),
@@ -428,10 +428,10 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('294.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'T.V.A. Collect\xe9e',
+                              'nom_compte': u'T.V.A. Collectée',
                               'numero_compte_credit': u'44571',
                               'numero_compte_debit': u''}],
-              'intitule': u'Remise ch\xe8que XXXXXXX r\xe8glement facture 2011-02',
+              'intitule': u'Remise chèque XXXXXXX règlement facture 2011-02',
               u'numero_ligne_debut': 64,
               u'numero_ligne_fin': 69},
              {'date': datetime.date(2011, 7, 5),
@@ -445,7 +445,7 @@ u"""+---------------------------------------------------------------------------
                               'nom_compte': u'Banques',
                               'numero_compte_credit': u'512',
                               'numero_compte_debit': u''}],
-              'intitule': u'Traitement mois de juin g\xe9rant.',
+              'intitule': u'Traitement mois de juin gérant.',
               u'numero_ligne_debut': 72,
               u'numero_ligne_fin': 75},
              {'date': datetime.date(2011, 8, 8),
@@ -459,7 +459,7 @@ u"""+---------------------------------------------------------------------------
                               'nom_compte': u'Banques',
                               'numero_compte_credit': u'512',
                               'numero_compte_debit': u''}],
-              'intitule': u'Ch\xe8que XXXXXXY Cotisation trimestrielle RSI/Pr\xe9vadi\xe8s.',
+              'intitule': u'Chèque XXXXXXY Cotisation trimestrielle RSI/Prévadiès.',
               u'numero_ligne_debut': 78,
               u'numero_ligne_fin': 82},
              {'date': datetime.date(2011, 9, 2),
@@ -470,7 +470,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u'512'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('980.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44587'},
                              {u'credit': Decimal('5980.00'),
@@ -480,7 +480,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('980.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'T.V.A. Collect\xe9e',
+                              'nom_compte': u'T.V.A. Collectée',
                               'numero_compte_credit': u'44571',
                               'numero_compte_debit': u''}],
               'intitule': u'Virement MyClient1 ZZZZZZZZZZZ Facture 2011-01',
@@ -513,7 +513,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('2156.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'44587',
                               'numero_compte_debit': u''}],
               'intitule': u'Facture 2011-04 MyClient1 Prestation aout 2011',
@@ -522,17 +522,17 @@ u"""+---------------------------------------------------------------------------
              {'date': datetime.date(2011, 9, 30),
               u'ecritures': [{u'credit': Decimal('0.00'),
                               u'debit': Decimal('1274.00'),
-                              'nom_compte': u'TVA collect\xe9',
+                              'nom_compte': u'TVA collecté',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44571'},
                              {u'credit': Decimal('33.66'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'TVA d\xe9ductible sur autres biens et services',
+                              'nom_compte': u'TVA déductible sur autres biens et services',
                               'numero_compte_credit': u'44566',
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('1240.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'TVA \xe0 d\xe9caisser',
+                              'nom_compte': u'TVA à décaisser',
                               'numero_compte_credit': u'44551',
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('0.34'),
@@ -546,7 +546,7 @@ u"""+---------------------------------------------------------------------------
              {'date': datetime.date(2011, 10, 6),
               u'ecritures': [{u'credit': Decimal('0.00'),
                               u'debit': Decimal('1240.00'),
-                              'nom_compte': u'TVA \xe0 d\xe9caisser',
+                              'nom_compte': u'TVA à décaisser',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44551'},
                              {u'credit': Decimal('1240.00'),
@@ -554,7 +554,7 @@ u"""+---------------------------------------------------------------------------
                               'nom_compte': u'Banques',
                               'numero_compte_credit': u'512',
                               'numero_compte_debit': u''}],
-              'intitule': u'Ch\xe8que WWWWWWW R\xe8glement de la TVA trimestrielle',
+              'intitule': u'Chèque WWWWWWW Règlement de la TVA trimestrielle',
               u'numero_ligne_debut': 112,
               u'numero_ligne_fin': 116},
              {'date': datetime.date(2011, 11, 1),
@@ -570,7 +570,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('882.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'44587',
                               'numero_compte_debit': u''}],
               'intitule': u'Facture 2011-05 MyClient1 Prestation septembre 2011',
@@ -584,12 +584,12 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u'6411-URSF1'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('153.31'),
-                              'nom_compte': u'Charges - cotisations URSSAF - CSG/RDS d\xe9ductible',
+                              'nom_compte': u'Charges - cotisations URSSAF - CSG/RDS déductible',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'6411-URSF2'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('86.89'),
-                              'nom_compte': u'Charges - cotisations URSSAF - CSG/RDS non-d\xe9ductible',
+                              'nom_compte': u'Charges - cotisations URSSAF - CSG/RDS non-déductible',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'6411-URSF3'},
                              {u'credit': Decimal('402.00'),
@@ -597,7 +597,7 @@ u"""+---------------------------------------------------------------------------
                               'nom_compte': u'Banques',
                               'numero_compte_credit': u'512',
                               'numero_compte_debit': u''}],
-              'intitule': u'Ch\xe8que ZZZZZZZ Cotisation sociales Urssaf 4\xe8me trimestre.',
+              'intitule': u'Chèque ZZZZZZZ Cotisation sociales Urssaf 4ème trimestre.',
               u'numero_ligne_debut': 125,
               u'numero_ligne_fin': 131},
              {'date': datetime.date(2011, 12, 1),
@@ -622,12 +622,12 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u'512'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('2156.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44587'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('882.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44587'},
                              {u'credit': Decimal('18538.00'),
@@ -637,12 +637,12 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('2156.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'T.V.A. Collect\xe9e',
+                              'nom_compte': u'T.V.A. Collectée',
                               'numero_compte_credit': u'44571',
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('882.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'T.V.A. Collect\xe9e',
+                              'nom_compte': u'T.V.A. Collectée',
                               'numero_compte_credit': u'44571',
                               'numero_compte_debit': u''}],
               'intitule': u'Virement MyClient1 WWWWWWWWWW Facture 2011-04, 2011-05',
@@ -661,7 +661,7 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('1372.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'44587',
                               'numero_compte_debit': u''}],
               'intitule': u'Facture 2011-06 MyClient3',
@@ -670,12 +670,12 @@ u"""+---------------------------------------------------------------------------
              {'date': datetime.date(2011, 12, 31),
               u'ecritures': [{u'credit': Decimal('0.00'),
                               u'debit': Decimal('3038.00'),
-                              'nom_compte': u'TVA collect\xe9',
+                              'nom_compte': u'TVA collecté',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44571'},
                              {u'credit': Decimal('3038.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'TVA \xe0 d\xe9caisser',
+                              'nom_compte': u'TVA à décaisser',
                               'numero_compte_credit': u'44551',
                               'numero_compte_debit': u''}],
               'intitule': u'Solde des comptes de TVA du 01/10/2011 au 31/12/2011',
@@ -684,7 +684,7 @@ u"""+---------------------------------------------------------------------------
              {'date': datetime.date(2011, 12, 31),
               u'ecritures': [{u'credit': Decimal('0.00'),
                               u'debit': Decimal('13156.00'),
-                              'nom_compte': u'Clients - Factures \xe0 \xe9tablir',
+                              'nom_compte': u'Clients - Factures à établir',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'4181'},
                              {u'credit': Decimal('11000.00'),
@@ -694,10 +694,10 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('2156.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'44587',
                               'numero_compte_debit': u''}],
-              'intitule': u'Prestation MyClient1 d\xe9cembre 2011',
+              'intitule': u'Prestation MyClient1 décembre 2011',
               u'numero_ligne_debut': 160,
               u'numero_ligne_fin': 164},
              {'date': datetime.date(2012, 1, 1),
@@ -708,15 +708,15 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u'706'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('2156.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44587'},
                              {u'credit': Decimal('13156.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Clients - Factures \xe0 \xe9tablir',
+                              'nom_compte': u'Clients - Factures à établir',
                               'numero_compte_credit': u'4181',
                               'numero_compte_debit': u''}],
-              'intitule': u'Prestation MyClient1 d\xe9cembre 2011',
+              'intitule': u'Prestation MyClient1 décembre 2011',
               u'numero_ligne_debut': 169,
               u'numero_ligne_fin': 173},
              {'date': datetime.date(2012, 1, 3),
@@ -732,21 +732,21 @@ u"""+---------------------------------------------------------------------------
                               'numero_compte_debit': u''},
                              {u'credit': Decimal('2156.00'),
                               u'debit': Decimal('0.00'),
-                              'nom_compte': u'Taxes sur le CA sur factures \xe0 \xe9tablir',
+                              'nom_compte': u'Taxes sur le CA sur factures à établir',
                               'numero_compte_credit': u'44587',
                               'numero_compte_debit': u''}],
-              'intitule': u'Facture 2012-01 MyClient1 Prestation d\xe9cembre 2011',
+              'intitule': u'Facture 2012-01 MyClient1 Prestation décembre 2011',
               u'numero_ligne_debut': 176,
               u'numero_ligne_fin': 181},
              {'date': datetime.date(2012, 2, 1),
               u'ecritures': [{u'credit': Decimal('0.00'),
                               u'debit': Decimal('46.02'),
-                              'nom_compte': u'Charges - R\xe9ceptions',
+                              'nom_compte': u'Charges - Réceptions',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'6257'},
                              {u'credit': Decimal('0.00'),
                               u'debit': Decimal('3.78'),
-                              'nom_compte': u'T.V.A. d\xe9ductible sur autres biens et services',
+                              'nom_compte': u'T.V.A. déductible sur autres biens et services',
                               'numero_compte_credit': u'',
                               'numero_compte_debit': u'44566'},
                              {u'credit': Decimal('49.80'),
@@ -754,7 +754,7 @@ u"""+---------------------------------------------------------------------------
                               'nom_compte': u'Banques',
                               'numero_compte_credit': u'512',
                               'numero_compte_debit': u''}],
-              'intitule': u"Restaurant La Tour d'argent D\xe9jeuner d'affaire avec Steve Jobs 0.88\u20ac TVA 19.6% ; 2.90\u20ac TVA 7.0%",
+              'intitule': u"Restaurant La Tour d'argent Déjeuner d'affaire avec Steve Jobs 0.88€ TVA 19.6% ; 2.90€ TVA 7.0%",
               u'numero_ligne_debut': 184,
               u'numero_ligne_fin': 190}]
         )
